# pdb# - The Terminal Remote Debugger

pdb# (styled `pdbsharp`) is an experimental debugger base on pdb based on Textual and PDB's remote debugging protocol.

## Installation

### uv

Run pdb# without installation using `uvx pdbsharp`. Or install into your environment with `uv add pdbsharp` and run with `uv run pdbsharp`.

### pip

Install with `pip install pdbsharp` and run with `python -m pdbsharp`.

## Usage

Since pdb# extends Python's pdb module, all of the [debugger commands](https://docs.python.org/3/library/pdb.html#debugger-commands) available in pdb are also available in pdb#.

## Contributing

See [CONTRIBUTING.md](CONTRIBUTING.md) for development setup guidelines.
